@@ -4,12 +4,12 @@ use strict;
 use warnings;
 
 use Time::HiRes qw(time);
-use Math::BigInt;
+use Math::BigInt lib => 'GMP';
 use Bytes::Random::Secure qw(
   random_bytes random_bytes_base64 random_bytes_hex
 );
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 sub get_random_bits {
 
@@ -20,12 +20,13 @@ sub get_random_bits {
         NonBlocking => 1,
     );
 
-    return Math::BigInt->from_bin( unpack( 'B*', $random->bytes(5) ) );
+    return Math::BigInt->from_bin( unpack( 'B*', $random->bytes(3) ) );
 }
 
 sub get_millisecond_timestamp {
 
-    my $time = Math::BigInt->new(time * 100000);
+    my $epoch = 946702800;
+    my $time = Math::BigInt->new( int( ( time - $epoch ) * 1000 ));
     return $time;
 }
 
@@ -39,7 +40,7 @@ sub get_flake {
     my $timestamp = $self->get_millisecond_timestamp;
     my $random = $self->get_random_bits;
 
-    my $flake = $timestamp->blsft(41);
+    my $flake = $timestamp->blsft(23);
     $flake->bior($random);
 
     return $flake->as_hex;
